@@ -30,6 +30,8 @@ class FlaUiError(AttributeError):
     KeyboardExtractionFailed = "Can't extract value from input"
     ListviewItemNotFound = "Item name '{}' could not be found in column with index '{}'"
     FalseSyntax = "Incorrect syntax usage '{}'"
+    ArgumentShouldBeList = "The given argument should be an array"
+    ArgumentShouldNotBeList = "The given argument should not be an array"
 
     @staticmethod
     def raise_fla_ui_error(message):
