@@ -5,9 +5,12 @@ from FlaUILibrary.flaui.uia import UIA
 class UIA2(UIA):
     """UIA2 window automation module for a centralized communication handling between robot keywords and flaui. """
 
-    def __init__(self):
-        """Creates UIA2 window automation module. """
-        super().__init__()
+    def __init__(self, timeout=1000):
+        """
+        Creates UIA2 window automation module.
+        ``timeout`` is the default waiting value to repeat element find action. Default value is 1000ms.
+        """
+        super().__init__(timeout)
         self._automation = UIA2Automation()
         super().register_action(self._automation)  # pylint: disable=maybe-no-member
 
