@@ -4,6 +4,9 @@ from FlaUILibrary.flaui.module import (ToggleButton, Element)
 
 
 class RadioButtonKeywords:
+    """
+    Interface implementation from robotframework usage for radio button keywords.
+    """
 
     def __init__(self, module):
         """Constructor for radiobutton keywords.
@@ -26,7 +29,7 @@ class RadioButtonKeywords:
         | msg        | string | Custom error message          |
 
         Examples:
-        | Check Radiobutton  <XPATH> |
+        | Select Radiobutton  <XPATH> |
 
         """
         element = self._module.action(Element.Action.GET_ELEMENT, identifier, msg)
